@@ -279,7 +279,7 @@ def attach_tooltips():
     This is necessary so that the search later finds operations by name in categories.
     The search searches in the tooltip.
 
-    Todo: This only works if the tools-menu is initizaled.
+    Todo: This only works if the tools-menu is initialized.
           We should alternatively search for menu names + functions in npe2.
     """
     # attach tooltips
@@ -468,8 +468,12 @@ def operations_in_menu(category, search_string: str = None):
         return []
     menu_name = category.tools_menu
     choices = filter_operations(menu_name)
+
+    all_ops = all_operations()
+
     if search_string is not None and len(search_string) > 0:
-        choices = [c for c in choices if search_string in c.lower()]
+        choices_dict = {k: all_ops[k] for k in choices}
+        choices = [c for c, v in choices_dict.items() if search_string in c.lower() or (v.__doc__ is not None and search_string in v.__doc__.lower())]
     choices = [c.split(">")[1].strip() for c in choices]
     choices = sorted(choices, key=str.casefold)
 
@@ -550,9 +554,9 @@ def filter_categories(search_string: str = ""):
 
     all_categories = {}
     for k, c in CATEGORIES.items():
-        if callable(c) or search_string in c.tool_tip.lower():
-            new_c = copy(c)
-            all_categories[k] = new_c
+        #if callable(c) or search_string in c.tool_tip.lower():
+        new_c = copy(c)
+        all_categories[k] = new_c
 
     category_found = False
     result = {}
